# ---------------------------------------------------------------------------------------------
#  Copyright (c) Leo Hanisch. All rights reserved.
#  Licensed under the MIT License. See LICENSE.txt in the project root for license information.
# ---------------------------------------------------------------------------------------------

"""pylintfileheader module"""

from __future__ import absolute_import
from pylintfileheader import plugin, file_header_checker  # noqa: F401


register = plugin.register # pylint: disable=invalid-name
